@@ -10,7 +10,9 @@ class Nbody():
         t_inst = self.predict_instability_time(sim, tmax, archive_filename, archive_interval)
         
         minP = np.min([p.P for p in sim.particles[1:sim.N_real]])
-        if t_inst >= 1e9*minP:
+        if tmax is None:
+            tmax = 1e9*minP
+        if t_inst >= tmax:
             return 1
         else:
             return 0
@@ -29,7 +31,7 @@ class Nbody():
 
         try:
             sim.integrate(tmax, exact_finish_time=0)
-        except:# rebound.Collision:
+        except rebound.Collision:
             if archive_filename:
                 sim.simulationarchive_snapshot(archive_filename)
             return sim.t
